OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bookmarks",
    "No file provided for import" : "هیچ پرونده ای برای واردکردن ارائه نشده است",
    "Unsupported file type for import" : "این نوع فایل برای افزودن پشتیبانی نمی شود",
    "A Bookmark manager for Nextcloud" : "یک مدیر نشانک برای نکست کلود",
    "Select bookmark" : "نشانک را انتخاب کنید",
    "Details" : "جزئیات",
    "Rename" : "تغییرنام",
    "Move" : "انتقال",
    "Delete" : "حذف",
    "Move selection" : "انتخاب را جابجا کنید",
    "Delete selection" : "انتخاب را حذف کنید",
    "Select all" : "انتخاب همه",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
    "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
    "New" : "جدید",
    "New folder" : "پوشه جدید",
    "Enter a link" : "پیوند را وارد کنید",
    "Enter folder title" : "عنوان پوشه را وارد کنید",
    "Submit" : "ارسال",
    "Cancel" : "لغو",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
    "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["در حال انتقال %n نشانک","در حال انتقال %n نشانک ها"],
    "Recent" : "اخیر",
    "Untagged" : "غیرقابل تشخیص",
    "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
    "Import" : "وارد کردن",
    "Export" : "گرفتن خروجی",
    "Client apps" : "برنامه های مشتری",
    "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
    "Bookmarklet" : "نشانک",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "این مورد را به نشانک های مرورگر خود بکشید و روی آن کلیک کنید تا سریع یک صفحه وب نشانک گذاری شود",
    "Add to {instanceName}" : "افزودن به {instanceName}",
    "Clear data" : "داده روشن",
    "Delete all bookmarks" : "حذف همه نشانک ها",
    "Do you really want to delete all your bookmarks?" : "آیا واقعاً می خواهید تمام نشانک های خود را حذف کنید؟",
    "Title" : "عنوان",
    "Link" : "Link",
    "Tags" : "برچسب‌ها",
    "Notes" : "یادداشت ها",
    "Owner" : "صاحب",
    "Sharing" : "اشتراک گذاری",
    "Select a user or group" : "کاربر یا گروهی را انتخاب کنید",
    "Share link" : "لینک را به اشتراک بگذارید",
    "Copy link" : "کپی کردن لینک",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Link copied" : "پیوند کپی شد",
    "Privacy" : "حریم خصوصی",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "نشانک ها سعی می کنند به صفحات وب اضافه شده دسترسی پیدا کنند تا به طور خودکار اطلاعات مربوط به آنها اضافه شود.",
    "Enable accessing and collecting information from the web pages you add" : "دسترسی و جمع آوری اطلاعات از صفحات وب اضافه شده را فعال کنید",
    "Performance" : "کارایی",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "حداکثر تعداد نشانک های مجاز در هر حساب. (0 بدون محدودیت است ؛ پیش فرض هیچ محدودیتی نیست)",
    "Previews" : "پیش نمایش ها",
    "Screeenly" : "صفحه نمایش",
    "You can either sign up for free at screeenly.com or setup your own server." : "می توانید به صورت رایگان در screeenly.com ثبت نام کنید یا سرور خود را راه اندازی کنید.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "Failed to load settings" : "تنظیمات بارگیری نشد",
    "Failed to save settings" : "تنظیمات ذخیره نشدند",
    "Add a bookmark" : "یک نشانک اضافه کنید",
    "This URL is already bookmarked! Overwrite?" : "این URL از قبل نشانک گذاری شده است! دوباره نشانک گذاری شود؟",
    "Enter bookmark title" : "عنوان نشانک را وارد کنید",
    "Enter bookmark URL" : "URL نشانک را وارد کنید",
    "Folder" : "پوشه",
    "Save" : "ذخیره",
    "Failed to find existing bookmark" : "یافتن نشانک موجود انجام نشد",
    "Failed to create bookmark" : "ایجاد نشانک انجام نشد",
    "Failed to save bookmark" : "ذخیره نشانک انجام نشد",
    "Failed to move bookmark" : "انتقال نشانک انجام نشد",
    "Failed to delete bookmark" : "حذف نشانک انجام نشد",
    "Failed to load tags" : "بارگیری برچسب ها انجام نشد",
    "Failed to load folders" : "بارگیری پوشه ها انجام نشد",
    "Failed to delete folder" : "پوشه حذف نشد",
    "Failed to create folder" : "پوشه ایجاد نشد",
    "Failed to fetch bookmarks." : "واکشی نشانک ها انجام نشد.",
    "Failed to change setting" : "تنظیم تغییر نکرد",
    "Bookmarks feed" : "بازخورد نشانک ها"
},
"nplurals=2; plural=(n > 1);");
